﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Olap.FlatData;
using Infragistics.Olap;
using Infragistics.Olap.Data;
using Infragistics.Controls.Grids;

namespace HidingTotalsOnLayoutLoaded.WPF
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private ObservableCollection<CarsSales> _flatData;

        public ObservableCollection<CarsSales> FlatData
        {
            get
            {
                if (this._flatData == null)
                {
                    this._flatData = new ObservableCollection<CarsSales>();
                }

                return this._flatData;
            }
        }


        public MainWindow()
        {
            InitializeComponent();
            Loaded += new RoutedEventHandler(PivotGridFlatDataCarSales_Loaded);
            pivotGrid.DataSource.Columns.CollectionChanging += new System.Collections.Specialized.NotifyCollectionChangedEventHandler(Columns_CollectionChanging);
        }

        #region EventHandlers

        void PivotGridFlatDataCarSales_Loaded(object sender, RoutedEventArgs e)
        {
            this.CreateFlatData();
            (LayoutRoot.Resources["FlatDataConnectionSettings"] as FlatDataConnectionSettings).ItemsSource = this.FlatData;
            pivotGrid.DataSource = LayoutRoot.Resources["flatDataSource"] as IOlapViewModel;
            dataSelector.DataSource = LayoutRoot.Resources["flatDataSource"] as IOlapViewModel;
        }

        void Columns_CollectionChanging(object sender, System.Collections.Specialized.NotifyCollectionChangedEventArgs e)
        {
            if (e.NewItems != null)
            {
                IFilterViewModel filterViewModel = e.NewItems[0] as IFilterViewModel;
                if (filterViewModel != null && filterViewModel.FilterMembers != null)
                {
                    IFilterMember filterMember = filterViewModel.FilterMembers[0];
                    int maxLevel = filterMember.Member.ParentLevel.ParentHierarchy.Levels.Count;
                    DrillDownMember(filterMember, 3);
                }
            }
        }

        void pivotGrid_LayoutLoaded(object sender, EventArgs e)
        {
            pivotGrid.LayoutLoaded -= new EventHandler<EventArgs>(pivotGrid_LayoutLoaded);

            foreach (PivotDataColumn c in pivotGrid.DataColumns.Where(x => x.IsTotal))
            {
                c.IsVisible = false;
            }

        }

        private void MeasuresRadioChanged_Checked(object sender, RoutedEventArgs e)
        {
            pivotGrid.DataSource.Measures.Clear();

            RadioButton radio = sender as RadioButton;

            if (radio.Content.ToString() == "Cost")
            {
                pivotGrid.LayoutLoaded += new EventHandler<EventArgs>(pivotGrid_LayoutLoaded);

                IMeasureViewModel cost = pivotGrid.DataSource.CreateMeasureViewModel(pivotGrid.DataSource.Cube.Measures["Cost"]);
                pivotGrid.DataSource.Measures.Add(cost);
            }

            if (radio.Content.ToString() == "Units")
            {
                IMeasureViewModel units = pivotGrid.DataSource.CreateMeasureViewModel(pivotGrid.DataSource.Cube.Measures["Units"]);
                pivotGrid.DataSource.Measures.Add(units);
            }
        }

        #endregion

        #region private Methods

        private void CreateFlatData()
        {
            this._flatData = new ObservableCollection<CarsSales>(CarsSales.GenerateData());
        }

        private static void DrillDownMember(IFilterMember filterMember, int level)
        {
            if (filterMember.Member.LevelDepth > level || filterMember.FilterMembers == null)
            {
                return;
            }

            filterMember.IsExpanded = true;
            foreach (IFilterMember childMember in filterMember.FilterMembers)
            {
                DrillDownMember(childMember, level);
            }
        }

        #endregion
    }
}
